<?php

namespace skin\main;

// articles page
// -------------

use Post;
use PostLanguage;
use function is_admin;

function index($ctx) {
    return <<<HTML
<div class="page"><div class="blog-post-text">
    <div class="clearfix index-book">
        <div class="index-book-image-wrap">
            <a class="index-book-image" id="index-book-image" href="https://files.4in1.ws/Images/4in1-cover-en.png" target="_blank" data-link-template="https://files.4in1.ws/Images/4in1-cover-{lang}.png"></a>
        </div>
        
        <a class="index-dl-line" href="https://files.4in1.ws/4in1-en.pdf?4" onmouseenter="IndexPage.setCoverLang('en')">
            <b>Download in English</b><br>
            <div class="index-dl-line-info">
                PDF <span class="bullet">&#8226;</span> 379 pp. <span class="bullet">&#8226;</span> 25 MiB
            </div>
        </a>
        <a class="index-dl-line" href="https://files.4in1.ws/4in1-ru.pdf?4" onmouseenter="IndexPage.setCoverLang('ru')">
            <b>Скачать на русском</b>
            <div class="index-dl-line-info">
                PDF <span class="bullet">&#8226;</span> 453 стр. <span class="bullet">&#8226;</span> 29 MiB
            </div>
        </a>
        
        <div class="index-book-updates">
            Released by <a href="https://kiwibyrd.org" target="_blank">kiwi arXiv</a> & <a href="https://kniganews.org" target="_blank">kniganews</a> in 2023<br>
            English translation by Eline Cat<br>
            <div class="index-book-updates-link-wrap">
                <a href="/updates/">The book update log</a>
            </div>
        </div>
    </div>  
</div></div>
HTML;

}

function articles($ctx, array $posts, PostLanguage $selected_lang): string {
if (empty($posts))
    return $ctx->articlesEmpty($selected_lang);

return <<<HTML
<div class="blog-list">
    {$ctx->articlesPostsTable($posts, $selected_lang)}
</div>
HTML;
}

function articlesEmpty($ctx, PostLanguage $selected_lang) {
return <<<HTML
<div class="empty">
    {$ctx->lang('blog_no')}
    {$ctx->articlesRightLinks($selected_lang->value)}
</div>
HTML;
}

function articlesPostsTable($ctx, array $posts, PostLanguage $selected_lang): string {
$ctx->year = 3000;
return <<<HTML
<div class="blog-list-table-wrap">
    <table class="blog-list-table" width="100%" cellspacing="0" cellpadding="0">
        {$ctx->for_each($posts, fn($post, $i) => $ctx->articlesPostRow($i, $post, $selected_lang))}
    </table>
</div>
HTML;
}

function articlesPostRow($ctx, int $index, Post $post, PostLanguage $selected_lang): string {
$year = $post->getYear();
$date = $post->getDate();
$url = $post->getUrl($selected_lang);

$pt = $post->getText($selected_lang);
$title = $pt->title;

return <<<HTML
{$ctx->if_true($ctx->year > $year, $ctx->articlesIndexYearLine, $year, $index === 0, $selected_lang->value)}
<tr class="blog-item-row{$ctx->if_not($post->visible, ' ishidden')}">
    <td class="blog-item-date-cell">
        <span class="blog-item-date">{$date}</span>
    </td>
    <td class="blog-item-title-cell">
        <a class="blog-item-title" href="{$url}">{$title}</a>
    </td>
</tr>
HTML;
}

function articlesIndexYearLine($ctx, $year, $show_right_links, string $selected_lang): string {
$ctx->year = $year;
return <<<HTML
<tr class="blog-item-row-year">
    <td class="blog-item-date-cell"><span>{$year}</span></td>
    <td>
        {$ctx->if_true($show_right_links, $ctx->articlesRightLinks($selected_lang))}
    </td>
</tr>
HTML;
}


function articlesRightLinks($ctx, string $selected_lang) {
$links = [
    ['url' => $selected_lang != 'en' ? '/articles/' : null, 'label' => lang('lang_en')],
    ['url' => $selected_lang != 'ru' ? '/articles/?lang=ru' : null, 'label' => lang('lang_ru')],
];
if (is_admin()) {
    $links[] = ['url' => '/articles/write/?lang='.$selected_lang, 'label' => 'write'];
}

return <<<HTML
<div class="blog-item-right-links">
    {$ctx->for_each($links, fn($link, $index) => $ctx->articlesRightLink($link['url'], $link['label'], $index))}
</div>
HTML;
}

function articlesRightLink($ctx, $url, string $label, int $index) {
    $buf = '';
    if ($index > 0)
        $buf .= ' <span class="blog-links-separator">|</span> ';
    $buf .= !$url ? $label : '<a href="'.$url.'">'.$label.'</a>';
    return $buf;
}


// any page
// --------

function page($ctx, $page_url, $short_name, $unsafe_html) {
$html = <<<HTML
<div class="page">
    <!--<div class="blog-post-title-nav">
        <a href="/">{$ctx->lang('index')}</a> <span>&rsaquo;</span>
    </div>-->
    {$ctx->if_admin($ctx->pageAdminLinks, $page_url, $short_name)}
    <div class="blog-post-text">{$unsafe_html}</div>
</div>
HTML;

return [$html, markdownThemeChangeListener()];
}

function pageAdminLinks($ctx, $url, $short_name) {
return <<<HTML
<div class="page-edit-links">
    <a href="{$url}edit/">{$ctx->lang('edit')}</a>
    <a href="{$url}delete/?token={$ctx->csrf('delpage'.$short_name)}" onclick="return confirm('{$ctx->lang('pages_page_delete_confirmation')}')">{$ctx->lang('delete')}</a>
</div>
HTML;

}


// post page
// ---------

function post($ctx, $id, $title, $unsafe_html, $unsafe_toc_html, $date, $visible, $url, string $lang, $other_langs) {
$html = <<<HTML
<div class="blog-post-wrap2">
    <div class="blog-post-wrap1">
        <div class="blog-post">
            {$ctx->bc([
                ['url' => '/articles/?lang='.$lang, 'text' => $ctx->lang('articles')]    
            ])}
            <div class="blog-post-title">
                <h1>{$title}</h1>
                <div class="blog-post-date">
                    {$ctx->if_not($visible, $ctx->lang('blog_post_hidden').' |')}
                    {$date}
                    {$ctx->if_true($other_langs, $ctx->postOtherLangs($url, $other_langs))}
                    {$ctx->if_admin($ctx->postAdminLinks, $url, $id, $lang)}
                </div>
            </div>
            <div class="blog-post-text">{$unsafe_html}</div>
        </div>
        {$ctx->if_true($unsafe_toc_html, $ctx->postToc, $unsafe_toc_html)}
    </div>
</div>
HTML;

return [$html, markdownThemeChangeListener()];
}

function postOtherLangs($ctx, $url, $other_langs) {
    $buf = '';
    foreach ($other_langs as $lang) {
        $buf .= ' | <a href="'.$url.'?lang='.$lang.'">'.$ctx->lang('blog_read_in_'.$lang).'</a>';
    }
    return $buf;
}

function postToc($ctx, $unsafe_toc_html) {
return <<<HTML
<div class="blog-post-toc">
    <div class="blog-post-toc-wrap">
        <div class="blog-post-toc-inner-wrap">
            <div class="blog-post-toc-title">{$ctx->lang('toc')}</div>
            {$unsafe_toc_html}
        </div>
    </div>
</div>
HTML;

}

function postAdminLinks($ctx, $url, $id, string $lang) {
return <<<HTML
| <a href="{$url}edit/?lang={$lang}">{$ctx->lang('edit')}</a>
| <a href="{$url}delete/?token={$ctx->csrf('delpost'.$id)}" onclick="return confirm('{$ctx->lang('blog_post_delete_confirmation')}')">{$ctx->lang('delete')}</a>
HTML;
}

function markdownThemeChangeListener() {
return <<<JS
ThemeSwitcher.addOnChangeListener(function(isDark) {
    var nodes = document.querySelectorAll('.md-image-wrap');
    for (var i = 0; i < nodes.length; i++) {
        var node = nodes[i];
        var alpha = parseInt(node.getAttribute('data-alpha'), 10);
        if (!alpha)
            continue;
        var div = node.querySelector('a > div');
        if (!div) {
            console.warn('could not found a>div on this node:', node);
            continue;
        }
        var style = div.getAttribute('style');
        if (isDark) {
            style = style.replace(/(a[\d]+x[\d]+)\.jpg/, '$1_dark.jpg');
        } else {
            style = style.replace(/(a[\d]+x[\d]+)_dark\.jpg/, '$1.jpg');
        }
        div.setAttribute('style', style);
    }
});
JS;
}
